<?php
session_start();

// Check if the user is logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    header('Location: login.php'); // Redirect to the login page if not logged in
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage APIs</title>
    <style>
       body {
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f0f8ff; /* Light, soft background */
            color: #333;
            display: flex;
            word-break:break-all;
            flex-direction: column; /* Ensure content is always vertically scrollable */
             min-height: 100vh; /* Ensure the body always takes up at least full screen height */
        }

        h1, h2 {
            text-align: center;
            color: teal; /* Darker shade for the headers */
            margin-bottom: 1px;
            text-shadow: 1px 1px 2px black; /* Light text shadow for depth */
        }

       .container {
            width: 90%; /* Reduce width for small screen */
            max-width: 600px;
            margin: 5px auto;
            background-color: #ffffff; /* White background */
            padding: 20px;
            border-radius: 12px; /* Smoother border-radius */
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            box-sizing: border-box;
             flex-grow: 1; /* Let the container grow vertically */
              display: flex;
              flex-direction: column;
        }


        form {
            margin-bottom: 20px;
            display: flex;
            flex-direction: column;
            gap: 10px;
        }

        form label {
            display: block;
            margin-bottom: 5px;
            color: #555; /* Slightly darker labels */
        }

        form input[type="text"] {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 6px; /* Slightly more rounded input */
             box-sizing: border-box;
        }

        form input[type="submit"] {
           background-color: #28a745;
           color: white;
           border: none;
           border-radius: 6px;
           padding: 10px 15px;
           cursor: pointer;
             transition: background-color 0.3s ease;
        }

        form input[type="submit"]:hover {
            background-color: #218838;
        }

        ul {
            padding-left: 0;
             list-style: none;
             flex-grow: 1;
              display: flex;
              flex-direction: column;
              gap: 5px;
        }

      li {
            background-color: #f9f9f9;
            padding: 10px;
            border-radius: 8px;
            display: flex;
            justify-content: space-between;
            align-items: center;
               word-wrap: break-word;
               box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

          li form {
            margin: 0;
            display: inline;
        }

       li form input[type="submit"]{
            background-color: #dc3545;
            color: white;
            border: none;
            border-radius: 6px;
            padding: 5px 10px;
            cursor: pointer;
             transition: background-color 0.3s ease;
        }
       li form input[type="submit"]:hover{
            background-color: #c82333;
        }


        p {
            text-align: center;
            margin-bottom: 5px;
            color: #28a745;
            background-color: #f0fdf4;
            padding: 5px 0;
             border-radius: 6px;
        }

        /* Adjustments for smaller screens */
        @media (max-width: 768px) {
             .container {
                 padding: 5px;
                width: 95%;
            }
             li {
                flex-direction: column; /* Stack content vertically on small screens */
                align-items: flex-start;
                 gap: 5px;
            }
              li form {
                margin-top: 5px;
                display: block;
            }
             li form input[type="submit"] {
                width: auto;
                display: block;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>11labs APIs List</h1>

        <?php
            // Path to the JSON file
            $jsonFile = 'APIs.json';

            // Function to load JSON data
            function loadJsonData($jsonFile) {
                if (file_exists($jsonFile)) {
                    $jsonData = file_get_contents($jsonFile);
                    return json_decode($jsonData, true);
                } else {
                    return ['apis' => []]; // Return an empty apis array if the file doesn't exist
                }
            }

            // Function to save JSON data
            function saveJsonData($jsonFile, $data) {
                file_put_contents($jsonFile, json_encode($data, JSON_PRETTY_PRINT));
            }

             // Function to get the next available key name
            function getNextKeyName($data) {
                $nextKeyNumber = 1;
                 if(isset($data['apis']) && !empty($data['apis'])){
                    $existingKeys = array_column($data['apis'], 'name');
                        sort($existingKeys);
                            for ($i=1; ; $i++) {
                                if(!in_array("Key" . $i, $existingKeys)){
                                $nextKeyNumber = $i;
                                break;
                                }
                            }
                 }
                return "Key" . $nextKeyNumber;
            }
             // Function to re-index the keys after delete
             function reIndexKeys($data){
                if (isset($data['apis']) && is_array($data['apis'])) {
                        $newApis = [];
                        for ($i = 0; $i < count($data['apis']); $i++) {
                            $newApi = $data['apis'][$i];
                            $newApi['name'] = "Key". ($i+1);
                            $newApis[] = $newApi;
                        }
                        $data['apis'] = $newApis;

                    }
                    return $data;
            }


           // Check if the form to delete an API was submitted
            if (isset($_POST['delete_api'])) {
                $apiToDelete = $_POST['api_to_delete'];
                $data = loadJsonData($jsonFile);

                if ($data) {
                    // Remove the selected API from the list
                    foreach ($data['apis'] as $key => $api) {
                        if ($api['name'] === $apiToDelete) {
                            unset($data['apis'][$key]);
                            break;
                        }
                    }
                    $data['apis'] = array_values($data['apis']); // Re-index the array
                    $data = reIndexKeys($data);
                     saveJsonData($jsonFile, $data);
                    echo "<p>API '$apiToDelete' has been successfully deleted.</p>";
                 }
             }

            // Check if the form to add a new API was submitted
            if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['api_key']) ) {
                $apiKey = $_POST['api_key'];
                $data = loadJsonData($jsonFile);
                 $nextKeyName = getNextKeyName($data);

                // Add the new API to the 'apis' array
                $newApi = [
                    "name" => $nextKeyName,
                    "xi-api-key" => $apiKey,
                     "voice_ids" => []
                ];


                //add Marcus voice
                $urlMarcus = "https://api.us.elevenlabs.io/v1/voices/add/9ad8a0e0919d3206eabd2485d79f503178aaad3f993962c01354a8557fd44941/TJdGgFoRwIpDGaLZCRzq";

                // Set up the data to be sent in JSON format
                $dataElevenLabs = [
                    "new_name" => "Marcus - authoritative and deep"
                ];

                // Initialize cURL session
                $chMarcus = curl_init($urlMarcus);

                // Set cURL options
                curl_setopt($chMarcus, CURLOPT_RETURNTRANSFER, true);  // Return response instead of outputting it
                curl_setopt($chMarcus, CURLOPT_POST, true);  // This is a POST request
                curl_setopt($chMarcus, CURLOPT_HTTPHEADER, [
                    "User-Agent: Mozilla/5.0",
                    "Content-Type: application/json",
                    "xi-api-key: $apiKey"  // Set the API key
                ]);
                curl_setopt($chMarcus, CURLOPT_POSTFIELDS, json_encode($dataElevenLabs));  // Convert data to JSON

                // Execute the request
                $responseMarcus = curl_exec($chMarcus);
                $voiceIdMarcus = "";
                // Check for errors
                if (curl_errno($chMarcus)) {
                    echo "Error: " . curl_error($chMarcus);
                } else {
                    // Output the response
                    $responseDataMarcus = json_decode($responseMarcus, true);
                   if(isset($responseDataMarcus['voice_id'])){
                       $voiceIdMarcus = $responseDataMarcus['voice_id'];
                        echo "<p>Marcus voice added Successfully: Voice ID: " . $voiceIdMarcus."</p>";
                         $newApi['voice_ids']['marcus'] = $voiceIdMarcus;

                    }
                   else{
                      echo "<p>Marcus voice added Successfully, but No Voice ID is Returned</p>";
                    }
                }

                // Close the cURL session
                curl_close($chMarcus);


                //add Victoria voice
                $urlVictoria = "https://api.us.elevenlabs.io/v1/voices/add/9ad8a0e0919d3206eabd2485d79f503178aaad3f993962c01354a8557fd44941/lKqU0Pi4tWfYA871XVtN";

                // Set up the data to be sent in JSON format
                $dataElevenLabs = [
                     "new_name" => "Victoria - classy and mature"
                 ];

                // Initialize cURL session
                $chVictoria = curl_init($urlVictoria);

                // Set cURL options
                curl_setopt($chVictoria, CURLOPT_RETURNTRANSFER, true);  // Return response instead of outputting it
                curl_setopt($chVictoria, CURLOPT_POST, true);  // This is a POST request
                curl_setopt($chVictoria, CURLOPT_HTTPHEADER, [
                     "User-Agent: Mozilla/5.0",
                     "Content-Type: application/json",
                     "xi-api-key: $apiKey"  // Set the API key
                 ]);
                curl_setopt($chVictoria, CURLOPT_POSTFIELDS, json_encode($dataElevenLabs));  // Convert data to JSON

                 // Execute the request
                 $responseVictoria = curl_exec($chVictoria);
                 $voiceIdVictoria = "";
                 // Check for errors
                if (curl_errno($chVictoria)) {
                    echo "Error: " . curl_error($chVictoria);
                } else {
                    // Output the response
                   $responseDataVictoria = json_decode($responseVictoria, true);
                   if(isset($responseDataVictoria['voice_id'])){
                        $voiceIdVictoria = $responseDataVictoria['voice_id'];
                        echo "<p>Victoria voice added Successfully: Voice ID: " . $voiceIdVictoria."</p>";
                         $newApi['voice_ids']['victoria'] = $voiceIdVictoria;
                    }
                  else{
                    echo "<p>Victoria voice added Successfully, but No Voice ID is Returned</p>";
                  }
                }
                 // Close the cURL session
                curl_close($chVictoria);

                 //add neal voice
                 $urlNeal = "https://api.us.elevenlabs.io/v1/voices/add/20fd2d803be06a425d7b6392de589393921b8f62bfa400e433a2a96ce5dd4aa1/pGmf9n00N8tgWVDhbQAY";

                // Set up the data to be sent in JSON format
                $dataElevenLabs = [
                     "new_name" => "Neal"
                  ];

                // Initialize cURL session
                 $chNeal = curl_init($urlNeal);

                // Set cURL options
                curl_setopt($chNeal, CURLOPT_RETURNTRANSFER, true);  // Return response instead of outputting it
                 curl_setopt($chNeal, CURLOPT_POST, true);  // This is a POST request
                 curl_setopt($chNeal, CURLOPT_HTTPHEADER, [
                    "User-Agent: Mozilla/5.0",
                     "Content-Type: application/json",
                     "xi-api-key: $apiKey"  // Set the API key
                  ]);
                 curl_setopt($chNeal, CURLOPT_POSTFIELDS, json_encode($dataElevenLabs));  // Convert data to JSON

               // Execute the request
                $responseNeal = curl_exec($chNeal);
               $voiceIdNeal = "";
                // Check for errors
                 if (curl_errno($chNeal)) {
                     echo "Error: " . curl_error($chNeal);
                 } else {
                    // Output the response
                    $responseDataNeal = json_decode($responseNeal, true);
                    if(isset($responseDataNeal['voice_id'])){
                        $voiceIdNeal = $responseDataNeal['voice_id'];
                        echo "<p>Neal voice added Successfully: Voice ID: " . $voiceIdNeal."</p>";
                       $newApi['voice_ids']['neal'] = $voiceIdNeal;

                     }
                   else{
                     echo "<p>Neal voice added Successfully, but No Voice ID is Returned</p>";
                    }
                }

                 // Close the cURL session
                 curl_close($chNeal);

               $data['apis'][] = $newApi;
                  // Encode and write updated data back to the JSON file
                 saveJsonData($jsonFile, $data);
                echo "<p>New API has been successfully added!</p>";


            }
        ?>

        <!-- Form to add new API -->
        <h2>Add a New API</h2>
       <form method="POST" id="addForm" onsubmit="return confirm('Are you sure you want to add this new API key?');">
            <label for="api_key">Enter New API Key Below: 👇</label>
            <input type="text" id="api_key" name="api_key" required><br>
           <input type="submit" value="Click Here to Add  New API">
        </form>


        <?php
            // Show all existing APIs
            $data = loadJsonData($jsonFile);
            if (isset($data['apis']) && !empty($data['apis'])) {
                    // Sort APIs in descending order by key name
                usort($data['apis'], function($a, $b) {
                        return strnatcmp($b['name'], $a['name']);
                    });
                echo "<h2>👇List Of Existing APIs👇</h2>";
                echo "<ul>";
                foreach ($data['apis'] as $api) {
                 echo "<li><span style='word-wrap: break-word;'><strong>{$api['name']}</strong> - {$api['xi-api-key']}
                 - Marcus Voice ID: " . (isset($api['voice_ids']['marcus']) ? $api['voice_ids']['marcus'] : 'N/A') . "
                  - Victoria Voice ID: " . (isset($api['voice_ids']['victoria']) ? $api['voice_ids']['victoria'] : 'N/A') . "
                 - Neal Voice ID: " . (isset($api['voice_ids']['neal']) ? $api['voice_ids']['neal'] : 'N/A') . " </span>

                       <form method='POST' style='display:inline' onsubmit=\"return confirm('Are you sure you want to delete this API key?');\">
                            <input type='hidden' name='api_to_delete' value='{$api['name']}'>
                            <input type='submit' name='delete_api' value='Delete'>
                        </form></li>";
                }
                echo "</ul>";
            } else {
                echo "<p>No API keys added yet.</p>";
            }
        ?>
    </div>
</body>
</html>