<?php
$dataFile = 'cookies.json';
$data = file_exists($dataFile) ? json_decode(file_get_contents($dataFile), true) : [];
$email = isset($_GET['email']) ? $_GET['email'] : null;
if (!isset($data[$email])) {
    echo "Email not found";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Image Generation</title>
    <style>
         body {
            font-family: 'Arial', sans-serif;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: flex-start;
            min-height: 100vh;
            margin: 20px;
            background-color: #f4f4f4;
            color: #333;
        }

         h1 {
            color: #2c3e50;
            margin-bottom: 20px;
            text-align: center;
        }
         form {
            background-color: #fff;
            padding: 30px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            width: 600px;
            display: flex;
            flex-direction: column;
             align-items: center;
            transition: transform 0.3s ease-in-out;
            margin-bottom: 20px;
        }
        form:hover {
           transform: scale(1.02);
       }

        textarea {
            width: calc(100% - 22px);
            padding: 10px;
            margin-bottom: 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
            box-sizing: border-box;
            transition: border-color 0.3s ease;
            font-family: inherit;
            min-height: 80px;
            resize: vertical;
            outline: none;
        }
        input[type="number"] {
            width: calc(50% - 22px);
             padding: 10px;
             margin-bottom: 15px;
            border: 1px solid #ddd;
           border-radius: 4px;
           box-sizing: border-box;
            transition: border-color 0.3s ease;
              outline: none;
        }

         textarea:focus,input[type="number"]:focus {
            border-color: #3498db;
            outline: none;
        }
          button {
            background-color: #3498db;
            color: white;
            padding: 10px 15px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s ease;
             margin-bottom: 10px;
        }
        button:hover {
            background-color: #217dbb;
        }
         #status {
            text-align: center;
            margin-top: 20px;
            font-weight: bold;
        }
        #image-container {
          margin-top: 20px;
          text-align: center;
        }

        #image-container img {
             max-width: 100%;
             max-height: 500px;
             border-radius: 8px;
        }
       .size-inputs{
            display: flex;
           width: 100%;
           justify-content: space-between;
        }
    </style>
</head>
<body>
    <h1>Image Generator</h1>
    <form id="imageForm">
        <textarea id="prompt" placeholder="Enter your prompt here">A hyper realistic, highly detailed image of an old book mockup titled "Control Your Mouth & Mind". The book mockup should be placed on a natural bokeh background. In the footer of the book cover, include the Author name "AudioBook Legends" with an old typography which is clearly visible, also add relevant elements from title in the book cover.</textarea>
          <div class="size-inputs">
             <input type="number" id="width" placeholder="Width" value="1024" required>
            <input type="number" id="height" placeholder="Height" value="1024" required>
         </div>
        <button type="submit">Generate Image</button>
        <div id="status"></div>
    </form>
    <div id="image-container"></div>
    <script>
        document.getElementById('imageForm').addEventListener('submit', function(event) {
            event.preventDefault();
            const prompt = document.getElementById('prompt').value;
              const width = document.getElementById('width').value;
              const height = document.getElementById('height').value;
            const statusDiv = document.getElementById('status');
            const imageContainer = document.getElementById('image-container');
            statusDiv.textContent = 'Generating...';
            imageContainer.innerHTML = '';

           const email = "<?php echo $email; ?>";

            // First API Request (addTask.php)
           fetch('addTask.php?email='+ email, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
               body: 'prompt=' + encodeURIComponent(prompt) + '&width=' + encodeURIComponent(width) + '&height=' + encodeURIComponent(height),
            })
            .then(response => response.json())
            .then(data => {
               if(data && data[0] && data[0].result && data[0].result.data && data[0].result.data.json && data[0].result.data.json[0]){
                        const uuid = data[0].result.data.json[0].uuid;
                         statusDiv.textContent = 'Status: ' + data[0].result.data.json[0].status;
                        // Start Polling function
                         pollForImage(uuid,statusDiv,imageContainer,email);
                     } else if (data && data.error) {
                         statusDiv.textContent = 'Error: ' + data.error;
                     } else {
                         statusDiv.textContent = 'Error generating image.';
                     }
            })
            .catch(error => {
                statusDiv.textContent = 'Error generating image.';
                console.error('Error:', error);
            });
        });

        function pollForImage(uuid,statusDiv,imageContainer,email) {
           const interval = setInterval(() => {
             fetch('getTask.php?email=' + email, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: 'uuid=' + encodeURIComponent(uuid),
                })
                .then(response => response.json())
                 .then(data => {
                     if(data && data[0] && data[0].result && data[0].result.data && data[0].result.data.json && data[0].result.data.json[0]){
                        const task = data[0].result.data.json[0];
                        statusDiv.textContent = 'Status: ' + task.status;
                        if (task.status === 'completed' && task.s3_url) {
                            clearInterval(interval);
                             imageContainer.innerHTML = `<img src="${task.s3_url}" alt="Generated Image">`;
                            statusDiv.textContent = 'Image Generated Successfully';
                        } else if (task.status === 'error') {
                            clearInterval(interval);
                            statusDiv.textContent = 'Error: ' + task.error_message;
                        }
                    } else if (data && data.error){
                         statusDiv.textContent = 'Error: ' + data.error;
                          clearInterval(interval);
                    } else {
                        statusDiv.textContent = 'Error generating image.';
                         clearInterval(interval);
                    }
                })
                .catch(error => {
                     statusDiv.textContent = 'Error generating image.';
                     clearInterval(interval);
                    console.error('Error:', error);
                });

            }, 1000); // Check every 1 second
        }
    </script>
</body>
</html>