<?php

// Function to load JSON data
function loadJsonData($jsonFile) {
    if (file_exists($jsonFile)) {
        $jsonData = file_get_contents($jsonFile);
        return json_decode($jsonData, true);
    } else {
        return ['apis' => []]; // Return an empty apis array if the file doesn't exist
    }
}

// Function to save JSON data
function saveJsonData($jsonFile, $data) {
    file_put_contents($jsonFile, json_encode($data, JSON_PRETTY_PRINT));
}

$apiJsonFile = 'APIs.json';
$expiredApiJsonFile = 'ExpiredAPIs.json';
$apiData = loadJsonData($apiJsonFile);
$expiredApiData = loadJsonData($expiredApiJsonFile);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>API Usage Details</title>
    <link rel="stylesheet" href="style.css?v=0.1" />
    <style>
        #usageTable {
            width: 100%;
            border-collapse: collapse;
            margin-top: 5px;
        }
        #usageTable th, #usageTable td {
            border: 1px solid black;
            padding: 1px;
            text-align: center;
        }
        #usageTable th {
            background-color: #f2f2f2;
        }
        .api-key-button {
            border: none;
            padding: 1px 1px;
            font-size: 12px;
            margin-bottom: 1px;
            cursor: pointer;
            background-color: #007bff;
            color: #fff;
        }
        .voice-list {
            margin-top: 1px;
            padding: 1px;
            border: 1px solid black;
            background-color: #f9f9f9;
        }
        .voice-list select {
            width: 100%;
            padding: 1px;
            border: 1px solid black;
        }
       #updateButton {
            display: none; /* Initially hide the button */
             background-color: #28a745;
            color: white;
            border: none;
            border-radius: 6px;
            padding: 10px 15px;
            cursor: pointer;
             transition: background-color 0.3s ease;
        }

      #updateButton:hover {
            background-color: #218838;
        }
    </style>
</head>
<body>
    <div id="voiceContainer" class="hidden">
        <h3>Available Voices</h3>
        <div id="voiceListContainer" class="voice-list">
            <select id="narrator-select"></select>
        </div>
    </div>

    <div id="usageTableContainer">
        <h3>All API Usage Details</h3>
        <table id="usageTable">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Total</th>
                    <th>Remaining</th>
                    <th>Used %</th>
                    <th>Tier</th>
                    <th>Reset</th>
                    <th>Quota</th>
                </tr>
            </thead>
            <tbody id="usageTableBody"></tbody>
        </table>
    </div>
       <button id="updateButton">Click Here to Update APIs.json</button>

<script>
        const voiceContainer = document.getElementById("voiceContainer");
        const narratorSelect = document.getElementById("narrator-select");
        const usageTableBody = document.getElementById("usageTableBody");
        const apiData = <?php echo json_encode($apiData); ?>;
         const expiredApiData = <?php echo json_encode($expiredApiData); ?>;
        let flaggedKeys = [];
         const BATCH_SIZE = 2;
        function debounce(func, delay) {
          let timeoutId;
            return function (...args) {
              clearTimeout(timeoutId);
            timeoutId = setTimeout(() => {
               func.apply(this, args);
            }, delay);
        };
    }

        async function fetchVoices(apiKey) {
            try {
                voiceContainer.classList.remove("hidden");
                narratorSelect.innerHTML = ""; // Clear options
                const response = await fetch("https://api.elevenlabs.io/v1/voices", {
                    headers: { "xi-api-key": apiKey },
                });

                if (!response.ok) {
                    throw new Error(`Failed to fetch voices. Status: ${response.status}`);
                }

                const { voices } = await response.json();
                if (voices.length === 0) {
                    narratorSelect.innerHTML = `<option disabled>No voices found</option>`;
                    return;
                }

                voices.forEach((voice) => {
                    const option = document.createElement("option");
                    option.value = voice.voice_id;
                    option.textContent = `${voice.name} - ${voice.labels.gender || "Unknown"} - ${voice.labels.use_case || "General"}`;
                    narratorSelect.appendChild(option);
                });
            } catch (error) {
                console.error("Error fetching voices:", error);
                alert("An error occurred while fetching voices.");
            }
        }

   async function fetchAllApiUsage() {
        flaggedKeys = [];
         usageTableBody.innerHTML = `<tr><td colspan="7">Loading...</td></tr>`; // Display loading message
        let hasQuotaExceeded = false;
        try {
            const apiKeys = apiData.apis;
            for (let i = 0; i < apiKeys.length; i += BATCH_SIZE) {
                const batch = apiKeys.slice(i, i + BATCH_SIZE);
                const apiPromises = batch.map(async (api) => {
                    const apiKey = api["xi-api-key"];
                    const name = api.name;
                    let quotaExceeded = false;
                      try {
                         const response = await fetch("https://api.elevenlabs.io/v1/user", {
                                 headers: { "xi-api-key": apiKey },
                        });

                         if (!response.ok) {
                                 throw new Error(`Failed to fetch usage for ${name}`);
                         }

                            const { subscription } = await response.json();
                                    const total = subscription.character_limit;
                                    const used = subscription.character_count;
                                    const remaining = total - used;
                                    const usagePercentage = ((used / total) * 100).toFixed(2);
                                    const tier = subscription.tier;
                                    const resetDate = new Date(subscription.next_character_count_reset_unix * 1000).toLocaleDateString();
                             if(remaining < 500){
                               quotaExceeded = true;
                                flaggedKeys.push(name);
                                hasQuotaExceeded = true;
                             }
                             return {
                                name,
                                apiKey,
                                total,
                                remaining,
                                usagePercentage,
                                tier,
                                resetDate,
                                quotaExceeded
                             }

                    } catch (usageError) {
                      console.error(usageError.message);
                      return {
                         name,
                         error: 'Error fetching usage',
                         quotaExceeded: false
                     };
                  }
                });
                const apiResults = await Promise.all(apiPromises);
                  if (i === 0) {
                     usageTableBody.innerHTML = ""; // Clear loading message when first batch is loaded
                  }

                 apiResults.forEach((result) => {
                    const row = document.createElement("tr");
                    let cell;
                    if (result.error) {
                        cell = document.createElement("td");
                      cell.textContent = result.name;
                      row.appendChild(cell);
                        cell = document.createElement("td");
                      cell.colSpan = 6;
                       cell.style.color = 'red';
                      cell.textContent = result.error;
                      row.appendChild(cell);
                  } else {
                      cell = document.createElement("td");
                        const button = document.createElement('button');
                        button.classList.add('api-key-button');
                        button.textContent = result.name;
                        button.setAttribute('data-api-key', result.apiKey);
                       cell.appendChild(button);
                       row.appendChild(cell);
                       cell = document.createElement("td");
                      cell.textContent = result.total.toLocaleString();
                      row.appendChild(cell);
                       cell = document.createElement("td");
                      cell.textContent = result.remaining.toLocaleString();
                       row.appendChild(cell);
                      cell = document.createElement("td");
                      cell.textContent = `${result.usagePercentage}%`;
                     row.appendChild(cell);
                     cell = document.createElement("td");
                      cell.textContent = result.tier;
                     row.appendChild(cell);
                      cell = document.createElement("td");
                      cell.textContent = result.resetDate;
                      row.appendChild(cell);
                      cell = document.createElement("td");
                      cell.style.color = result.quotaExceeded ? 'red' : 'green';
                      cell.textContent = result.quotaExceeded ? 'Yes' : 'No';
                      row.appendChild(cell);
                  }
                  usageTableBody.appendChild(row);
                 });
            }
              if(flaggedKeys.length > 0){
                   try {
                       const formData = new FormData();
                         formData.append('flaggedKeys', JSON.stringify(flaggedKeys));
                       const response = await fetch('updateapi.php', {
                            method: 'POST',
                            body: formData
                        });
                     if (!response.ok) {
                             console.error('Failed to update APIs.json.');
                     }
                 } catch (error) {
                    console.error('There was an error updating the APIs.json', error);
                }
             }
                document.querySelectorAll(".api-key-button").forEach((button) => {
                     button.addEventListener("click", () => {
                        const apiKey = button.getAttribute("data-api-key");
                        fetchVoices(apiKey);
                    });
                });
        } catch (error) {
            console.error("Error loading API usage:", error);
               usageTableBody.innerHTML = `<tr><td colspan="7" style="color: red;">Error loading API usage.</td></tr>`;
            alert("An error occurred while loading API usage details.");
        }
    }
        async function fetchVoices(apiKey) {
            try {
                voiceContainer.classList.remove("hidden");
                narratorSelect.innerHTML = ""; // Clear options
                const response = await fetch("https://api.elevenlabs.io/v1/voices", {
                    headers: { "xi-api-key": apiKey },
                });

                if (!response.ok) {
                    throw new Error(`Failed to fetch voices. Status: ${response.status}`);
                }

                const { voices } = await response.json();
                if (voices.length === 0) {
                    narratorSelect.innerHTML = `<option disabled>No voices found</option>`;
                    return;
                }

                voices.forEach((voice) => {
                    const option = document.createElement("option");
                    option.value = voice.voice_id;
                    option.textContent = `${voice.name} - ${voice.labels.gender || "Unknown"} - ${voice.labels.use_case || "General"}`;
                    narratorSelect.appendChild(option);
                });
            } catch (error) {
                console.error("Error fetching voices:", error);
                alert("An error occurred while fetching voices.");
            }
        }

        window.addEventListener("load", fetchAllApiUsage);
    </script>
</body>
</html>