const apiKey = 'AIzaSyC05lknqsDvsTMayrmY3JdSvdSNBYyCvFs'; // Replace with your actual API key!  ***DO NOT HARDCODE IN PRODUCTION***
const bookTitleInput = document.getElementById('bookTitle');
const generateChaptersBtn = document.getElementById('generateChaptersBtn');
const chaptersListTextarea = document.getElementById('chaptersList');
const generateExplanationsBtn = document.getElementById('generateExplanationsBtn');
const explanationsArea = document.getElementById('explanationsArea');
const logMessage = document.getElementById('logMessage'); // Add this line

const localStorageKey = 'audiobookData';

function loadData() {
    const storedData = localStorage.getItem(localStorageKey);
    if (storedData) {
        const data = JSON.parse(storedData);
        bookTitleInput.value = data.bookTitle || '';
        chaptersListTextarea.value = data.chapters || '';
        explanationsArea.value = data.explanations || '';
    }
}

function saveData() {
    const data = {
        bookTitle: bookTitleInput.value,
        chapters: chaptersListTextarea.value,
        explanations: explanationsArea.value,
    };
    localStorage.setItem(localStorageKey, JSON.stringify(data));
}

function clearData() {
    localStorage.removeItem(localStorageKey);
    bookTitleInput.value = '';
    chaptersListTextarea.value = '';
    explanationsArea.value = '';
}

function setLogMessage(message) {  // Helper function to update the log message
    logMessage.textContent = message;
}

async function generateChapters(bookTitle) {
    setLogMessage('Generating chapters...');  // Log message
    try {
        const response = await fetch('https://generativelanguage.googleapis.com/v1beta/models/gemini-1.5-flash:generateContent?key=' + apiKey, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                contents: [{
                    parts: [{
                        text: `Generate a list of 20 chapters for an audiobook about "${bookTitle}".  Return each chapter on a new line.`
                    }]
                }]
            }),
        });

        if (!response.ok) {
            throw new Error(`HTTP error! status: ${response.status}`);
        }

        const data = await response.json();
        const chapters = data.candidates[0].content.parts[0].text;
        chaptersListTextarea.value = chapters;
        saveData(); // Save after generating chapters
        setLogMessage('Chapters generated successfully.'); // Log success
    } catch (error) {
        console.error('Error generating chapters:', error);
        setLogMessage(`Error generating chapters: ${error.message}`);  // Log error
        alert('Error generating chapters. See console for details.');
    }
}

async function generateExplanation(chapterTitle, bookTitle) {
    setLogMessage(`Generating explanation for chapter: ${chapterTitle}`);
    try {
        const response = await fetch('https://generativelanguage.googleapis.com/v1beta/models/gemini-1.5-flash:generateContent?key=' + apiKey, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                contents: [{
                    parts: [{
                        text: `Write a detailed explanation of about 10000 words for the chapter "${chapterTitle}" in the audiobook "${bookTitle}".  Be comprehensive and engaging.  Return the text in segments of approximately 200 words, separated by the token '[[CHUNK_SEPARATOR]]'.`
                    }]
                }]
            }),
        });

        if (!response.ok) {
            throw new Error(`HTTP error! status: ${response.status}`);
        }

        const data = await response.json();
        const fullExplanation = data.candidates[0].content.parts[0].text;
        const explanationChunks = fullExplanation.split('[[CHUNK_SEPARATOR]]');
        setLogMessage(`Explanation generated for chapter: ${chapterTitle}`);
        return explanationChunks; // Return array of chunks
    } catch (error) {
        console.error('Error generating explanation for chapter:', chapterTitle, error);
        setLogMessage(`Error generating explanation for chapter: ${chapterTitle} - ${error.message}`);
        alert(`Error generating explanation for chapter: ${chapterTitle}. See console for details.`);
        return null; // Indicate failure
    }
}

async function* generateExplanationChunks(chapterTitle, bookTitle) {  // Generator function
    const explanationChunks = await generateExplanation(chapterTitle, bookTitle);
    if (explanationChunks) {
        for (const chunk of explanationChunks) {
            yield chunk;
        }
    } else {
        yield `**ERROR GENERATING EXPLANATION for ${chapterTitle}**`;
    }
}

async function generateAllExplanations() {
    const chapters = chaptersListTextarea.value.split('\n').filter(chapter => chapter.trim() !== '');
    const bookTitle = bookTitleInput.value;

    for (const chapter of chapters) {
        explanationsArea.value += `Chapter: ${chapter}\n\n`;

        const explanationGenerator = generateExplanationChunks(chapter, bookTitle);
        let done = false;

        while (!done) {
            const { value, done: thisDone } = await explanationGenerator.next();
            done = thisDone;

            if (value) {
                await new Promise(resolve => {
                    requestAnimationFrame(() => {
                        explanationsArea.value += value;
                        explanationsArea.scrollTop = explanationsArea.scrollHeight; // Scroll to bottom
                        saveData(); // Save periodically
                        resolve();
                    });
                });
            }
        }

        explanationsArea.value += `\n\n`; // Chapter separator
    }

    setLogMessage("All chapters processed.");
    console.log("All chapters processed.");
}

generateChaptersBtn.addEventListener('click', () => {
    const bookTitle = bookTitleInput.value;
    if (bookTitle) {
        clearData(); // Clear existing data when generating new chapters
        generateChapters(bookTitle);
    } else {
        alert('Please enter a book title or topic.');
    }
});

generateExplanationsBtn.addEventListener('click', () => {
    generateAllExplanations();
});

chaptersListTextarea.addEventListener('input', saveData); // Save when chapters are manually edited
explanationsArea.addEventListener('input', saveData);   //save when explanations are edited
bookTitleInput.addEventListener('input', saveData); // Save when book title changes

// Load data on page load
loadData();