const apiKey = 'AIzaSyC05lknqsDvsTMayrmY3JdSvdSNBYyCvFs'; // Replace with your actual API key!  ***DO NOT HARDCODE IN PRODUCTION***
const youtubeChannelSelect = document.getElementById('youtubeChannel');
const languageSelect = document.getElementById('language');
const bookTitleInput = document.getElementById('bookTitle');
const generateChaptersBtn = document.getElementById('generateChaptersBtn');
const chaptersListTextarea = document.getElementById('chaptersList');
const generateExplanationsBtn = document.getElementById('generateExplanationsBtn');
const explanationsArea = document.getElementById('explanationsArea');
const logMessage = document.getElementById('logMessage'); // Add this line

const localStorageKey = 'audiobookData';

function loadData() {
    const storedData = localStorage.getItem(localStorageKey);
    if (storedData) {
        const data = JSON.parse(storedData);
        youtubeChannelSelect.value = data.youtubeChannel || 'channel1'; // Default to channel1
        languageSelect.value = data.language || 'english'; // Default to english
        bookTitleInput.value = data.bookTitle || '';
        chaptersListTextarea.value = data.chapters || '';
        explanationsArea.value = data.explanations || '';
    }
}

function saveData() {
    const data = {
        youtubeChannel: youtubeChannelSelect.value,
        language: languageSelect.value,
        bookTitle: bookTitleInput.value,
        chapters: chaptersListTextarea.value,
        explanations: explanationsArea.value,
    };
    localStorage.setItem(localStorageKey, JSON.stringify(data));
}

function clearData() {
    localStorage.removeItem(localStorageKey);
  //  youtubeChannelSelect.value = 'channel1'; //reset to default channel
  //  languageSelect.value = 'english'; //reset to default language
   // bookTitleInput.value = '';
    chaptersListTextarea.value = '';
    explanationsArea.value = '';
}

function setLogMessage(message) {  // Helper function to update the log message
    logMessage.textContent = message;
}

async function generateChapters(bookTitle, youtubeChannel, language) {
    setLogMessage('Generating chapters...');  // Log message

    const chapterPrompt = getChapterPrompt(bookTitle, youtubeChannel, language);  // Get the prompt
    try {
        const response = await fetch('https://generativelanguage.googleapis.com/v1beta/models/gemini-1.5-flash:generateContent?key=' + apiKey, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                contents: [{
                    parts: [{
                        text: chapterPrompt,
                    }]
                }]
            }),
        });

        if (!response.ok) {
            throw new Error(`HTTP error! status: ${response.status}`);
        }

        const data = await response.json();
        const chapters = data.candidates[0].content.parts[0].text;
        chaptersListTextarea.value = chapters;
        saveData(); // Save after generating chapters
        setLogMessage('Chapters generated successfully.'); // Log success
    } catch (error) {
        console.error('Error generating chapters:', error);
        setLogMessage(`Error generating chapters: ${error.message}`);  // Log error
        alert('Error generating chapters. See console for details.');
    }
}

async function generateExplanation(chapterTitle, bookTitle, youtubeChannel, language) {
    setLogMessage(`Generating explanation for chapter: ${chapterTitle}`);

    const explanationPrompt = getExplanationPrompt(chapterTitle, bookTitle, youtubeChannel, language);
    try {
        const response = await fetch('https://generativelanguage.googleapis.com/v1beta/models/gemini-1.5-flash:generateContent?key=' + apiKey, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                contents: [{
                    parts: [{
                        text: explanationPrompt,
                    }]
                }]
            }),
        });

        if (!response.ok) {
            throw new Error(`HTTP error! status: ${response.status}`);
        }

        const data = await response.json();
        const fullExplanation = data.candidates[0].content.parts[0].text;
        const explanationChunks = fullExplanation.split('[[CHUNK_SEPARATOR]]');
        setLogMessage(`Explanation generated for chapter: ${chapterTitle}`);
        return explanationChunks; // Return array of chunks
    } catch (error) {
        console.error('Error generating explanation for chapter:', chapterTitle, error);
        setLogMessage(`Error generating explanation for chapter: ${chapterTitle} - ${error.message}`);
        alert(`Error generating explanation for chapter: ${chapterTitle}. See console for details.`);
        return null; // Indicate failure
    }
}

async function* generateExplanationChunks(chapterTitle, bookTitle, youtubeChannel, language) {  // Generator function
    const explanationChunks = await generateExplanation(chapterTitle, bookTitle, youtubeChannel, language);
    if (explanationChunks) {
        for (const chunk of explanationChunks) {
            yield chunk;
        }
    } else {
        yield `**ERROR GENERATING EXPLANATION for ${chapterTitle}**`;
    }
}

async function generateAllExplanations() {
    const chapters = chaptersListTextarea.value.split('\n').filter(chapter => chapter.trim() !== '');
    const bookTitle = bookTitleInput.value;
    const youtubeChannel = youtubeChannelSelect.value; // Get the selected channel
    const language = languageSelect.value;

    for (const chapter of chapters) {
        explanationsArea.value += `Chapter: ${chapter}\n\n`;

        const explanationGenerator = generateExplanationChunks(chapter, bookTitle, youtubeChannel, language);
        let done = false;

        while (!done) {
            const { value, done: thisDone } = await explanationGenerator.next();
            done = thisDone;

            if (value) {
                await new Promise(resolve => {
                    requestAnimationFrame(() => {
                        explanationsArea.value += value;
                        explanationsArea.scrollTop = explanationsArea.scrollHeight; // Scroll to bottom
                        saveData(); // Save periodically
                        resolve();
                    });
                });
            }
        }

        explanationsArea.value += `\n\n`; // Chapter separator
    }

    setLogMessage("All chapters processed.");
    console.log("All chapters processed.");
}

function getChapterPrompt(bookTitle, youtubeChannel, language) {
    const channelName = youtubeChannelSelect.options[youtubeChannelSelect.selectedIndex].text;

    if (language === 'hindi') {
      return `"${bookTitle}" विषय पर ${channelName} नामक YouTube चैनल के लिए एक ऑडियोबुक के लिए 20 अध्यायों की एक सूची जेनरेट करें। प्रत्येक अध्याय को एक नई पंक्ति में लौटाएं।`; // Hindi
    } else {
      return `Generate a list of 20 chapters for an audiobook about "${bookTitle}" for the ${channelName} YouTube channel. Return each chapter on a new line.`;
    }
}

function getExplanationPrompt(chapterTitle, bookTitle, youtubeChannel, language) {
    const channelName = youtubeChannelSelect.options[youtubeChannelSelect.selectedIndex].text;

    if (language === 'hindi') {
        return `"${bookTitle}" ऑडियोबुक में अध्याय "${chapterTitle}" के लिए ${channelName} नामक YouTube चैनल के लिए लगभग 10000 शब्दों में एक विस्तृत विवरण लिखें। व्यापक और आकर्षक बनें। प्रत्येक खंड के अंत में, इस कॉल टू एक्शन को जोड़ें: "अगर आपको यह ऑडियोबुक पसंद आ रही है, तो कृपया ${channelName} को लाइक, शेयर और सब्सक्राइब करें!" पाठ को लगभग 200 शब्दों के खंडों में लौटाएं, जिसे '[[CHUNK_SEPARATOR]]' टोकन द्वारा अलग किया गया है।`; // Hindi
    } else {
        return `Write a detailed explanation of about 10000 words for the chapter "${chapterTitle}" in the audiobook "${bookTitle}" for the ${channelName} YouTube channel. Be comprehensive and engaging. Return the text in segments of approximately 200 words, separated by the token '[[CHUNK_SEPARATOR]]'. Add this call to action to each chunk: "If you're enjoying this audiobook, please like, share, and subscribe to ${channelName}!"`;
    }
}

generateChaptersBtn.addEventListener('click', () => {
    const bookTitle = bookTitleInput.value;
    const youtubeChannel = youtubeChannelSelect.value;
    const language = languageSelect.value;

    if (bookTitle) {
        clearData(); // Clear existing data when generating new chapters
        generateChapters(bookTitle, youtubeChannel, language);
    } else {
        alert('Please enter a book title or topic.');
    }
});

generateExplanationsBtn.addEventListener('click', () => {
    generateAllExplanations();
});

youtubeChannelSelect.addEventListener('change', saveData); //save when channel changes
languageSelect.addEventListener('change', saveData); //save when language changes
chaptersListTextarea.addEventListener('input', saveData); // Save when chapters are manually edited
explanationsArea.addEventListener('input', saveData);   //save when explanations are edited
bookTitleInput.addEventListener('input', saveData); // Save when book title changes  <----- THIS IS IT!

// Load data on page load
loadData();