<?php
// Set JSON file path
$chatFile = 'chat.json';

// Initialize chat file if it doesn't exist
if (!file_exists($chatFile)) {
    file_put_contents($chatFile, json_encode([]));
}

// Function to get chat messages
function getChatMessages() {
    global $chatFile;
    $data = json_decode(file_get_contents($chatFile), true);
    return $data ?: [];
}

// Function to add a new chat message
function addChatMessage($message) {
    global $chatFile;
    $messages = getChatMessages();
    array_push($messages, $message);

    // Remove the oldest message if more than 10 messages exist
    if (count($messages) > 10) {
        array_shift($messages);
    }

    file_put_contents($chatFile, json_encode($messages));
}

// Function to delete a chat message
function deleteChatMessage($index) {
    global $chatFile;
    $messages = getChatMessages();
    if (isset($messages[$index])) {
        unset($messages[$index]);
        $messages = array_values($messages); // Re-index the array
        file_put_contents($chatFile, json_encode($messages));
    }
}

// Function to delete all chat messages
function deleteAllChatMessages() {
    global $chatFile;
    file_put_contents($chatFile, json_encode([])); // Empty the chat file
}

// Handle new chat message submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['message'])) {
$message = trim($_POST['message']); // Trim white spaces 
    if (!empty($message)) {
        addChatMessage(['message' => $message, 'timestamp' => time()]);
    }
    exit;
}

// Handle chat message deletion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_index'])) {
    $index = intval($_POST['delete_index']);
    deleteChatMessage($index);
    exit;
}

// Handle delete all request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_all'])) {
    deleteAllChatMessages();
    exit;
}

// Get chat messages for displaying in chatbox
$chatMessages = getChatMessages();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Anonymous Live Chat</title>
    <style>
        /* Neomorphic CSS */
        body {
            font-family: Arial, sans-serif;
            background-color: #e0e0e0;
            display: block;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
        }

        .chat-container {
            background: #e0e0e0;
            border-radius: 20px;
            box-shadow: 10px 10px 20px #bebebe, -10px -10px 20px #ffffff;
            padding: 20px;
            width: 90%;
            height: 70%;
            display: flex;
            flex-direction: column;
        }

        .chat-box {
            background: #e0e0e0;
            border-radius: 20px;
            box-shadow: inset 10px 10px 20px #bebebe, inset -10px -10px 20px #ffffff;
            padding: 10px;
            flex-grow: 1;
            overflow-y: auto;
            margin-bottom: 20px;
        }

        .chat-message {
            display: flex;
            flex-direction: column;
            align-items: flex-start;
            justify-content: space-between;
            background: #e0e0e0;
            padding: 10px;
            border-radius: 10px;
            box-shadow: 5px 5px 10px #bebebe, -5px -5px 10px #ffffff;
            margin-bottom: 10px;
            word-wrap: break-word;
            white-space: wrap;
            user-select: text;
            position: relative; /* Allow positioning of delete button */
        }

        .copy-button {
            background: #e0e0e0;
            border-radius: 5px;
            padding: 5px 10px;
            box-shadow: 5px 5px 10px #bebebe, -5px -5px 20px #ffffff;
            cursor: pointer;
            border: 2px solid teal;
            font-size: 15px;
        }

        .copy-button:hover {
            background: #d4d4d4;
        }

        .delete-button {
            position: absolute;
            top: 5px;
            right: 5px;
            background: transparent;
            border: none;
            cursor: pointer;
            color: red;
            font-size: 20px;
        }

        .chat-input {
            display: flex;
            flex-direction: column; /* Stack input and buttons vertically */
        }

        .input-field {
            width: 94%;
            height:50px;
            padding: 10px;
            border-radius: 10px;
            background: #e0e0e0;
            box-shadow: inset 5px 5px 10px #bebebe, inset -5px -5px 10px #ffffff;
            border: none;
            outline: none;
            margin-bottom: 10px; /* Space between input and buttons */
        }

        .submit-button, .delete-all-button {
            padding: 10px;
            border-radius: 10px;
            background: #e0e0e0;
            box-shadow: 5px 5px 10px #bebebe, -5px -5px 10px #ffffff;
            border: none;
            cursor: pointer;
            margin-top: 5px; /* Space between buttons */
        }

        .submit-button:hover, .delete-all-button:hover {
            background: #d4d4d4;
        }

        textarea.chat-textarea {
            width: 100%;
            height: 20vh;
            resize: none;
            border: none;
            background: transparent;
            outline: none;
            font-size: 16px;
            padding: 5px;
        }
    </style>
</head>
<body>
<center>
 <button type="button" class="delete-all-button" onclick="confirmDeleteAll()">Delete All Messages</button>
    </center>
<div class="chat-container">
    <div class="chat-box" id="chatBox">
        <?php foreach ($chatMessages as $index => $chat): ?>
            <div class="chat-message">
<textarea class="chat-textarea" readonly><?= htmlentities($chat['message'], ENT_QUOTES, 'UTF-8'); ?></textarea>
                <button class="copy-button" onclick="copyMessage(this)">Copy</button>
                <button class="delete-button" onclick="confirmDelete(<?= $index; ?>)">✖</button>
            </div>
        <?php endforeach; ?>
    </div>

    <form class="chat-input" id="chatForm">
        <textarea name="message" id="messageInput" class="input-field" placeholder="Type your message here..." required></textarea>
        <button type="submit" class="submit-button">Send</button>
       </form>
</div>

<script>
// JavaScript to handle live chat functionality
document.getElementById('chatForm').addEventListener('submit', function(e) {
    e.preventDefault();
    var message = document.getElementById('messageInput').value;

    // Send message via AJAX
    var xhr = new XMLHttpRequest();
    xhr.open('POST', '', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            // Clear input field
            document.getElementById('messageInput').value = '';
            // Reload chat messages
            loadChatMessages();
        }
    };
    xhr.send('message=' + encodeURIComponent(message));
});

function loadChatMessages() {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', '', true);
    xhr.onload = function() {
        if (xhr.status === 200) {
            var parser = new DOMParser();
            var doc = parser.parseFromString(xhr.responseText, 'text/html');
            var chatBox = doc.getElementById('chatBox');
            document.getElementById('chatBox').innerHTML = chatBox.innerHTML;
        }
    };
    xhr.send();
}

// Function to copy message to clipboard
function copyMessage(button) {
    var textarea = button.previousElementSibling; // Get the textarea next to the button
    textarea.select();
    document.execCommand('copy');
}

// Function to confirm deletion of a message
function confirmDelete(index) {
    if (confirm('Are you sure you want to delete this message?')) {
        deleteMessage(index);
    }
}

// Function to delete a message via AJAX
function deleteMessage(index) {
    var xhr = new XMLHttpRequest();
    xhr.open('POST', '', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            // Reload chat messages after deletion
            loadChatMessages();
        }
    };
    xhr.send('delete_index=' + index);
}

// Function to confirm deletion of all messages
function confirmDeleteAll() {
    if (confirm('Are you sure you want to delete all messages?')) {
        deleteAllMessages();
    }
}

// Function to delete all messages via AJAX
function deleteAllMessages() {
    var xhr = new XMLHttpRequest();
    xhr.open('POST', '', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            // Reload chat messages after deletion
            loadChatMessages();
        }
    };
    xhr.send('delete_all=1');
}

// Refresh chat every 5 seconds
setInterval(loadChatMessages, 5000);

// Scroll chat to the bottom when new messages are loaded
function scrollChatToBottom() {
    var chatBox = document.getElementById('chatBox');
    chatBox.scrollTop = chatBox.scrollHeight;
}
scrollChatToBottom();
</script>

</body>
</html>
