<?php
// Set JSON file path
$chatFile = 'chat.json';

// Initialize chat file if it doesn't exist
if (!file_exists($chatFile)) {
    file_put_contents($chatFile, json_encode([]));
}

// Function to get chat messages
function getChatMessages() {
    global $chatFile;
    $data = json_decode(file_get_contents($chatFile), true);
    return $data ?: [];
}

// Function to add a new chat message
function addChatMessage($message) {
    global $chatFile;
    $messages = getChatMessages();
    array_push($messages, $message);

    // Remove the oldest message if more than 10 messages exist
    if (count($messages) > 10) {
        array_shift($messages);
    }

    file_put_contents($chatFile, json_encode($messages));
}

// Function to delete a chat message
function deleteChatMessage($index) {
    global $chatFile;
    $messages = getChatMessages();
    if (isset($messages[$index])) {
        unset($messages[$index]);
        $messages = array_values($messages); // Re-index the array
        file_put_contents($chatFile, json_encode($messages));
    }
}

// Function to delete all chat messages
function deleteAllChatMessages() {
    global $chatFile;
    file_put_contents($chatFile, json_encode([])); // Empty the chat file
}

// Handle new chat message submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['message'])) {
    $message = trim($_POST['message']); // Trim white spaces 
    if (!empty($message)) {
        addChatMessage(['message' => $message, 'timestamp' => time()]);
    }
    exit;
}

// Handle chat message deletion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_index'])) {
    $index = intval($_POST['delete_index']);
    deleteChatMessage($index);
    exit;
}

// Handle delete all request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_all'])) {
    deleteAllChatMessages();
    exit;
}

// Get chat messages for displaying in chatbox
$chatMessages = getChatMessages();
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Anonymous Live Chat</title>
    <style>
        /* Styling for the chat application */
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .chat-container {
            background-color: white;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            width: 80%;
            max-width: 600px;
            height: 80%;
            display: flex;
            flex-direction: column;
            padding: 10px;
        }

        .chat-box {
            flex-grow: 1;
            overflow-y: auto;
            margin-bottom: 20px;
            padding-right: 10px;
        }

        .chat-message {
            background-color: #f1f1f1;
            border-radius: 10px;
            margin-bottom: 10px;
            padding: 10px;
            position: relative;
            word-wrap: break-word;
            display: inline-block;
            width: 100%;
            min-height: 30px;  /* Ensure the message bubble has a minimum height */
        }

        .message-text {
            font-family: monospace;
            font-size: 14px;
            white-space: pre-wrap;
            word-wrap: break-word;
            display: block;
            width: 100%;
            border: none;
            background: none;
            color: inherit;
            font-family: inherit;
            font-size: inherit;
            padding: 5px;
            resize: none;
            outline: none;
        }

        .message-buttons {
            position: absolute;
            bottom: 5px;
            right: 5px;
        }

        .copy-button, .delete-button {
            padding: 5px;
            margin-left: 5px;
            font-size: 12px;
            cursor: pointer;
        }

        .chat-input {
            display: flex;
            flex-direction: column;
        }

        .input-field {
            width: 100%;
            height: 50px;
            padding: 10px;
            border-radius: 10px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            font-size: 14px;
        }

        .submit-button, .delete-all-button {
            padding: 10px;
            border-radius: 10px;
            background: #5c6bc0;
            color: white;
            font-size: 14px;
            border: none;
            cursor: pointer;
        }

        .submit-button:hover, .delete-all-button:hover {
            background: #3f4c8c;
        }

        .message-textarea {
            width: 100%;
            min-height: 30px;
            resize: none;
            outline: none;
            white-space: pre-wrap;
            word-wrap: break-word;
        }
    </style>
</head>
<body>

<div class="chat-container">
    <!-- Button to delete all messages -->
    <center>
        <button type="button" class="delete-all-button" onclick="confirmDeleteAll()">Delete All Messages</button>
    </center>

    <!-- Chatbox to display messages -->
    <div class="chat-box" id="chatBox">
        <?php foreach ($chatMessages as $index => $chat): ?>
            <div class="chat-message">
                <div class="message-text"><?= htmlspecialchars($chat['message'], ENT_NOQUOTES, 'UTF-8') ?></div>
                <div class="message-buttons">
                    <button class="copy-button" onclick="copyMessage(this)">Copy</button>
                    <button class="delete-button" onclick="confirmDelete(<?= $index ?>)">Delete</button>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <!-- Chat Input -->
    <form class="chat-input" id="chatForm">
        <textarea name="message" id="messageInput" class="input-field" placeholder="Type your message here..." required></textarea>
        <button type="submit" class="submit-button">Send</button>
    </form>
</div>

<script>
// JavaScript to handle live chat functionality

// Handle message sending
document.getElementById('chatForm').addEventListener('submit', function(e) {
    e.preventDefault();
    var message = document.getElementById('messageInput').value;

    // Send message via AJAX
    var xhr = new XMLHttpRequest();
    xhr.open('POST', '', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            // Clear input field
            document.getElementById('messageInput').value = '';
            // Reload chat messages
            loadChatMessages();
        }
    };
    xhr.send('message=' + encodeURIComponent(message));
});

// Load chat messages from server
function loadChatMessages() {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', '', true);
    xhr.onload = function() {
        if (xhr.status === 200) {
            var parser = new DOMParser();
            var doc = parser.parseFromString(xhr.responseText, 'text/html');
            var chatBox = doc.getElementById('chatBox');
            document.getElementById('chatBox').innerHTML = chatBox.innerHTML;
        }
    };
    xhr.send();
}

// Copy message to clipboard
function copyMessage(button) {
    var messageDiv = button.closest('.chat-message');
    var messageText = messageDiv.querySelector('.message-text');

    // Select and copy the message text
    var range = document.createRange();
    range.selectNode(messageText);
    window.getSelection().removeAllRanges();
    window.getSelection().addRange(range);
    document.execCommand('copy');

    alert('Message copied!');
}

// Confirm delete message
function confirmDelete(index) {
    if (confirm('Are you sure you want to delete this message?')) {
        deleteMessage(index);
    }
}

// Delete message via AJAX
function deleteMessage(index) {
    var xhr = new XMLHttpRequest();
    xhr.open('POST', '', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            loadChatMessages();
        }
    };
    xhr.send('delete_index=' + index);
}

// Confirm delete all messages
function confirmDeleteAll() {
    if (confirm('Are you sure you want to delete all messages?')) {
        deleteAllMessages();
    }
}

// Delete all messages via AJAX
function deleteAllMessages() {
    var xhr = new XMLHttpRequest();
    xhr.open('POST', '', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            loadChatMessages();
        }
    };
    xhr.send('delete_all=true');
}
</script>

</body>
</html>

