
<?php
    // Function to load JSON data
    function loadJsonData($jsonFile) {
        if (file_exists($jsonFile)) {
            $jsonData = file_get_contents($jsonFile);
            return json_decode($jsonData, true);
        } else {
            return ['urls' => []]; // Return an empty urls array if the file doesn't exist
        }
    }

    // Function to save JSON data
    function saveJsonData($jsonFile, $data) {
        file_put_contents($jsonFile, json_encode($data, JSON_PRETTY_PRINT));
    }

     // Function to re-index the keys after delete
    function reIndexKeys($data){
        if (isset($data['urls']) && is_array($data['urls'])) {
                $newUrls = [];
                for ($i = 0; $i < count($data['urls']); $i++) {
                    $newUrl = $data['urls'][$i];
                    $newUrl['name'] = "Link". ($i+1);
                    $newUrls[] = $newUrl;
                }
                $data['urls'] = $newUrls;

            }
            return $data;
    }
     // Function to get the next available key name
    function getNextKeyName($data) {
        $nextKeyNumber = 1;
         if(isset($data['urls']) && !empty($data['urls'])){
            $existingKeys = array_column($data['urls'], 'name');
                sort($existingKeys);
                    for ($i=1; ; $i++) {
                        if(!in_array("Link" . $i, $existingKeys)){
                        $nextKeyNumber = $i;
                        break;
                        }
                    }
         }
        return "Link" . $nextKeyNumber;
    }

    $freeJsonFile = 'freeapiurl.json';
    $paidJsonFile = 'paidapiurl.json';
    $freeData = loadJsonData($freeJsonFile);
    $paidData = loadJsonData($paidJsonFile);

    // Handle add new free API URL
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['free_api_url']) ) {
        $freeApiUrl = $_POST['free_api_url'];
         $nextKeyName = getNextKeyName($freeData);

        $newUrl = [
            "name" => $nextKeyName,
             "url" => $freeApiUrl
          ];
         $freeData['urls'][] = $newUrl;

        saveJsonData($freeJsonFile, $freeData);
        echo "<p>New Free API URL has been successfully added!</p>";
    }
   // Handle add new paid API URL
     if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['paid_api_url']) ) {
        $paidApiUrl = $_POST['paid_api_url'];
         $nextKeyName = getNextKeyName($paidData);
        $newUrl = [
            "name" => $nextKeyName,
             "url" => $paidApiUrl
          ];
        $paidData['urls'][] = $newUrl;
        saveJsonData($paidJsonFile, $paidData);
          echo "<p>New Paid API URL has been successfully added!</p>";
    }

   // Check if the form to delete an free API URL was submitted
    if (isset($_POST['delete_free_api_url'])) {
        $apiUrlToDelete = $_POST['free_api_url_to_delete'];

        if ($freeData) {
            // Remove the selected API from the list
            foreach ($freeData['urls'] as $key => $url) {
                if ($url['name'] === $apiUrlToDelete) {
                    unset($freeData['urls'][$key]);
                    break;
                }
            }
            $freeData['urls'] = array_values($freeData['urls']); // Re-index the array
            $freeData = reIndexKeys($freeData);
             saveJsonData($freeJsonFile, $freeData);
            echo "<p>Free API Url '$apiUrlToDelete' has been successfully deleted.</p>";
         }
     }
     // Check if the form to delete an paid API URL was submitted
    if (isset($_POST['delete_paid_api_url'])) {
        $apiUrlToDelete = $_POST['paid_api_url_to_delete'];

        if ($paidData) {
            // Remove the selected API from the list
            foreach ($paidData['urls'] as $key => $url) {
                if ($url['name'] === $apiUrlToDelete) {
                    unset($paidData['urls'][$key]);
                    break;
                }
            }
            $paidData['urls'] = array_values($paidData['urls']); // Re-index the array
            $paidData = reIndexKeys($paidData);
             saveJsonData($paidJsonFile, $paidData);
           echo "<p>Paid API Url '$apiUrlToDelete' has been successfully deleted.</p>";
         }
     }


?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage API URLs</title>
     <style>
        body {
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f0f8ff; /* Light, soft background */
            color: #333;
            display: flex;
            word-break:break-all;
            flex-direction: column; /* Ensure content is always vertically scrollable */
             min-height: 100vh; /* Ensure the body always takes up at least full screen height */
        }

        h1, h2 {
            text-align: center;
            color: teal; /* Darker shade for the headers */
            margin-bottom: 1px;
            text-shadow: 1px 1px 2px black; /* Light text shadow for depth */
        }

       .container {
            width: 90%; /* Reduce width for small screen */
            max-width: 600px;
            margin: 5px auto;
            background-color: #ffffff; /* White background */
            padding: 20px;
            border-radius: 12px; /* Smoother border-radius */
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            box-sizing: border-box;
             flex-grow: 1; /* Let the container grow vertically */
              display: flex;
              flex-direction: column;
        }


        form {
            margin-bottom: 20px;
            display: flex;
            flex-direction: column;
            gap: 10px;
        }

        form label {
            display: block;
            margin-bottom: 5px;
            color: #555; /* Slightly darker labels */
        }

        form input[type="text"] {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 6px; /* Slightly more rounded input */
             box-sizing: border-box;
        }

        form input[type="submit"] {
           background-color: #28a745;
           color: white;
           border: none;
           border-radius: 6px;
           padding: 10px 15px;
           cursor: pointer;
             transition: background-color 0.3s ease;
        }

        form input[type="submit"]:hover {
            background-color: #218838;
        }

        ul {
            padding-left: 0;
             list-style: none;
             flex-grow: 1;
              display: flex;
              flex-direction: column;
              gap: 5px;
        }

      li {
            background-color: #f9f9f9;
            padding: 10px;
            border-radius: 8px;
            display: flex;
            justify-content: space-between;
            align-items: center;
               word-wrap: break-word;
               box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

          li form {
            margin: 0;
            display: inline;
        }

       li form input[type="submit"]{
            background-color: #dc3545;
            color: white;
            border: none;
            border-radius: 6px;
            padding: 5px 10px;
            cursor: pointer;
             transition: background-color 0.3s ease;
        }
       li form input[type="submit"]:hover{
            background-color: #c82333;
        }


        p {
            text-align: center;
            margin-bottom: 5px;
            color: #28a745;
            background-color: #f0fdf4;
            padding: 5px 0;
             border-radius: 6px;
        }

        /* Adjustments for smaller screens */
        @media (max-width: 768px) {
             .container {
                 padding: 5px;
                width: 95%;
            }
             li {
                flex-direction: column; /* Stack content vertically on small screens */
                align-items: flex-start;
                 gap: 5px;
            }
              li form {
                margin-top: 5px;
                display: block;
            }
             li form input[type="submit"] {
                width: auto;
                display: block;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Manage API URLs</h1>

        <h2>Add New Free API URL</h2>
          <form method="POST" onsubmit="return confirm('Are you sure you want to add this new URL?');">
            <label for="free_api_url">Enter Free API URL Below: 👇</label>
            <input type="text" id="free_api_url" name="free_api_url" required><br>
           <input type="submit" value="Click Here to Add  New Free API URL">
        </form>

         <h2>Add New Paid API URL</h2>
          <form method="POST" onsubmit="return confirm('Are you sure you want to add this new URL?');">
            <label for="paid_api_url">Enter Paid API URL Below: 👇</label>
            <input type="text" id="paid_api_url" name="paid_api_url" required><br>
           <input type="submit" value="Click Here to Add  New Paid API URL">
        </form>

        <?php
            if (isset($freeData['urls']) && !empty($freeData['urls'])) {
                 usort($freeData['urls'], function($a, $b) {
                        return strnatcmp($b['name'], $a['name']);
                    });
                echo "<h2>👇List Of Existing Free API URLs👇</h2>";
                echo "<ul>";
                foreach ($freeData['urls'] as $url) {
                    echo "<li><span style='word-wrap: break-word;'><strong>{$url['name']}</strong> - {$url['url']}</span>
                          <form method='POST' style='display:inline' onsubmit=\"return confirm('Are you sure you want to delete this URL?');\">
                              <input type='hidden' name='free_api_url_to_delete' value='{$url['name']}'>
                              <input type='submit' name='delete_free_api_url' value='Delete'>
                          </form>
                       </li>";
                }
                echo "</ul>";
            } else {
                echo "<p>No Free API URLs added yet.</p>";
            }

             if (isset($paidData['urls']) && !empty($paidData['urls'])) {
                usort($paidData['urls'], function($a, $b) {
                        return strnatcmp($b['name'], $a['name']);
                    });
                echo "<h2>👇List Of Existing Paid API URLs👇</h2>";
                echo "<ul>";
                foreach ($paidData['urls'] as $url) {
                    echo "<li><span style='word-wrap: break-word;'><strong>{$url['name']}</strong> - {$url['url']}</span>
                           <form method='POST' style='display:inline' onsubmit=\"return confirm('Are you sure you want to delete this URL?');\">
                              <input type='hidden' name='paid_api_url_to_delete' value='{$url['name']}'>
                              <input type='submit' name='delete_paid_api_url' value='Delete'>
                          </form>
                        </li>";
                }
                echo "</ul>";
            } else {
                echo "<p>No Paid API URLs added yet.</p>";
            }

        ?>
    </div>
</body>
</html>