<!DOCTYPE html>
<html>
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<head>
    <title>YouTube Channel Videos</title>
    <style>
        .video-list {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            justify-content: center;
        }

        .video-item {
            width: 300px;
            border: 1px solid #ccc;
            padding: 10px;
            text-align: center;
        }

        .video-item img {
            max-width: 100%;
        }

        .watched {
            background-color:red;
        }
        .watched button{
          background-color: #c1e0c1;
        }

       /* Mobile-Friendly Styles */
        @media (max-width: 600px) {
            .video-list {
                flex-direction: column; /* Stack videos on small screens */
                align-items: center;
            }
            .video-item {
                width: 90%; /* Make videos take most of the screen width */
            }
        }
    </style>
</head>
<body>
    <h1>YouTube Channel Videos</h1>
    
    <div id="channels-container">
       <?php
         
         $id = $_GET['id'] ?? null;  // Get id from the query or set it to null

        if ($id) {
            $jsonlink = $id . '_videos.json';
            $jsonWatch = $id . '_watched.json';
    
            $videoData = @file_get_contents($jsonlink); // Use @ to suppress warnings if the file doesn't exist

            if ($videoData) {
                 echo "<script> const youtubeVideos = " . $videoData . "; </script>";
            } else {
                 echo "<script> console.error('Video data file not found: " . $jsonlink . "'); </script>";
            }
         // Function to save watched videos to JSON file
        function saveWatchedVideos($jsonWatch, $watchedVideos) {
            $json = json_encode($watchedVideos, JSON_PRETTY_PRINT);
             if (file_put_contents($jsonWatch, $json) === false) {
                 error_log("Failed to save watched video data to: $jsonWatch");
                return false;
            }
            return true;
          }


         // Handle POST request to update watched status
        if($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['videoId']) && isset($_POST['watched'])) {
               $videoId = $_POST['videoId'];
               $watched = $_POST['watched'] === 'true';
               $watchedVideos = [];
            if (file_exists($jsonWatch)) {
                $watchedVideos = json_decode(file_get_contents($jsonWatch), true) ?: [];
            }
            if($watched) {
                 $watchedVideos[$videoId] = true;
             } else {
                unset($watchedVideos[$videoId]);
             }
              
            if (saveWatchedVideos($jsonWatch, $watchedVideos)) {
                header('Content-Type: application/json');
                echo json_encode(['success' => true]);
                exit();
            } else {
                 http_response_code(500); // Internal Server Error
                  echo json_encode(['success' => false, 'error' => 'Failed to save watched data.']);
                  exit();
                }
         }
        // Fetch watched videos on initial page load for local storage
         $watchedVideos = [];
         if (file_exists($jsonWatch)) {
             $watchedVideos = json_decode(file_get_contents($jsonWatch), true) ?: [];
         }
             echo "<script> const initialWatchedVideos = " . json_encode($watchedVideos) . "; </script>";

       } else {
              echo " <p> No ID passed in URL </p>";
       }
        ?>
    </div>
    <script>
        const channelsContainer = document.getElementById('channels-container');
        let watchedVideos = JSON.parse(localStorage.getItem('watchedVideos')) || {};

        if(initialWatchedVideos) {
               watchedVideos = initialWatchedVideos;
               localStorage.setItem('watchedVideos', JSON.stringify(watchedVideos));
            }
         
        async function createChannelList() {

             for(const channelName in youtubeVideos) {
                  for(const channelId in youtubeVideos[channelName]) {

                      const channelDiv = document.createElement('div');
                      channelDiv.innerHTML = `<h2>Videos From ${channelName}</h2>
                                      <div class="video-list" id="video-list-${channelId}">
                                          <!-- Videos will be added here -->
                                      </div>`;
                         channelsContainer.appendChild(channelDiv)
                        displayVideos(channelName,channelId);
                    }
              }
        }
         function displayVideos(channelName,channelId) {
             const videoListContainer = document.getElementById(`video-list-${channelId}`);
              if(youtubeVideos[channelName] && youtubeVideos[channelName][channelId]) {
                  youtubeVideos[channelName][channelId].forEach(item => {
                      const videoItem = document.createElement('div');
                       videoItem.classList.add('video-item');
                        if(watchedVideos[item.videoId]) {
                            videoItem.classList.add('watched');
                        }
                       videoItem.innerHTML = `
                        <img src="${item.thumbnail}" alt="${item.title}">
                            <h3>${item.title}</h3>
                            <a href="${item.link}" target="_blank">Watch Video</a>
                            <button onclick="toggleWatched(this, '${item.videoId}')" >${watchedVideos[item.videoId] ? 'Unwatch' : 'Watch'}</button>
                       `;
                      videoListContainer.appendChild(videoItem);

                 });
            }
         }
          async function toggleWatched(button, videoId) {
            const videoItem = button.closest('.video-item');
            const watched = !watchedVideos[videoId];


              if (watched) {
                   watchedVideos[videoId] = true;
                } else {
                    delete watchedVideos[videoId];
                 }
                 localStorage.setItem('watchedVideos', JSON.stringify(watchedVideos));

                // Update DOM immediatly after updating watched video object
                if(watched){
                     videoItem.classList.add('watched');
                    button.textContent = 'Unwatch';
                }else{
                    videoItem.classList.remove('watched');
                   button.textContent = 'Watch';
                }

             try {
                 const response = await fetch(window.location.href, {
                   method: 'POST',
                    headers: {
                      'Content-Type': 'application/x-www-form-urlencoded'
                     },
                   body: `videoId=${videoId}&watched=${watched}`
               });
                 if (!response.ok) {
                     console.error('Error updating watched status');
                   }
               } catch (error) {
                console.error('Error during fetch request: ',error);
               }
          }
       if(youtubeVideos) {
          createChannelList();
      }
    </script>
</body>
</html>