<?php
// Cache directory
$cacheDir = 'cache/';
if (!is_dir($cacheDir)) {
    mkdir($cacheDir, 0755, true); // Create cache directory if it doesn't exist
}

// Get category ID from the request
$catId = $_GET['catId'];

// API endpoint
$url = 'https://api.tresify.com/books/categories/' . $catId . '?pageNo=0&pageSize=100000000';

// Function to get cached book data
function getCachedBookData($id, $cacheDir) {
    $cacheFile = $cacheDir . $id . '.json';
    if (file_exists($cacheFile)) {
        return json_decode(file_get_contents($cacheFile), true);
    }
    return false;
}

// Function to cache book data
function cacheBookData($id, $data, $cacheDir) {
    $cacheFile = $cacheDir . $id . '.json';
    file_put_contents($cacheFile, json_encode($data, JSON_PRETTY_PRINT));
}

// Check if the category data is cached
$cachedBookData = getCachedBookData($catId, $cacheDir);

// If cached data is available, use it; otherwise, fetch from the API and cache it
if ($cachedBookData) {
    $data = $cachedBookData;
} else {
    // Path to token file
    $tokenFile = 'token/token.txt';
    if (!file_exists($tokenFile)) {
        die("Token file not found");
    }

    $token = file_get_contents($tokenFile);

    // Initialize cURL
    $ch = curl_init();

    // Set cURL options
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_ENCODING, 'gzip'); // Automatically decode gzip
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Authorization: ' . $token,
        'User-Agent: Dart/3.4 (dart:io)',
        'Accept-Language: en',
        'Content-Type: application/json',
        'Accept-Encoding: gzip'
    ]);

    // Execute cURL request and fetch response
    $response = curl_exec($ch);
    $data = json_decode($response, true);

    // Close the cURL session
    curl_close($ch);

    // Check if the response data is valid before caching
    if (is_array($data)) {
        cacheBookData($catId, $data, $cacheDir);
    }
}

// Display the data if it's valid
if (is_array($data)) {
    echo "<h1>Books List</h1>";
    echo "<div class='book-container'>"; // Start the book container

    foreach ($data as $book) {
        // Check if the individual book data is cached
        $cachedBook = getCachedBookData($book['id'], $cacheDir);

        // If cached book data is available, use it; otherwise, cache the new data
        if ($cachedBook) {
            $book = $cachedBook;
        } else {
            // Cache the individual book data
            cacheBookData($book['id'], $book, $cacheDir);
        }

        // Create a link for each book using its ID
        $bookLink = "ViewBook.php?id=" . htmlspecialchars($book['id']) . "&page=0";

        // Display each book as a card
        echo "<div class='book-card'>";
        if (!empty($book['imageUrl'])) {
            echo "<img src='" . htmlspecialchars($book['imageUrl']) . "' alt='Book Image' class='book-image'/>";
        }
        echo "<h1><a href='" . $bookLink . "'>" . htmlspecialchars($book['bookNameEnglish']) . "</a></h1>";
        echo "<p><strong>Book title:</strong> " . htmlspecialchars($book['bookName']) . "</p>";

        // Use strip_tags to allow certain HTML tags in the 'about' and 'forWhom' fields
        echo "<p><strong>About the Book:</strong> " . strip_tags($book['about'], '<p><ul><li><br>') . "</p>";
        echo "<p><strong>For Whom:</strong> " . strip_tags($book['forWhom'], '<p><ul><li><br>') . "</p>";
        
        echo "</div>"; // End of book card
    }

    echo "</div>"; // End of book container
} else {
    // Handle token expired or other errors
    echo "Token expired or failed to fetch data from API.";
}
?>

<!-- CSS Styles -->
<style>
    body {
        font-family: Arial, sans-serif;
        margin: 20px;
        background-color: #f4f4f4;
    }
    
    h1 {
        text-align: center;
        color: #333;
    }
    
    .book-container {
        display: flex;
        flex-wrap: wrap;
        justify-content: center;
        gap: 20px;
    }
    
    .book-card {
        background: white;
        border: 1px solid #ddd;
        border-radius: 5px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        width: 250px;
        transition: transform 0.2s;
    }
    
    .book-card:hover {
        transform: scale(1.05);
    }
    
    .book-image {
        max-width: 100%;
        border-radius: 5px;
    }
    
    h3 {
        margin: 10px 0;
        font-size: 18px;
        color: #007BFF;
    }
    
    a {
        text-decoration: none;
        color: inherit;
    }
    
    p {
        margin: 5px 0;
        color: #555;
    }
</style>
