<?php
// Set header for UTF-8 output
header("Content-Type: text/plain; charset=UTF-8");

// Get the video ID from query parameter
$id = $_GET['id'] ?? '';

// Validate video ID
if (empty($id)) {
    echo "Invalid or missing video ID.";
    exit;
}

// URL for fetching Hindi transcript
$urlHindi = "https://youtubetotranscript.com/transcript?v=$id&current_language_code=en-IN&translated_language_code=hi";

// Function to fetch content using cURL with timeout and error handling
function fetchContent($url, $timeout = 10) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_TIMEOUT, $timeout); // Timeout in seconds
    curl_setopt($ch, CURLOPT_FAILONERROR, true); // Fail on HTTP errors
    $content = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

    if (curl_errno($ch) || $httpCode >= 400) {
        curl_close($ch);
        return false;
    }
    curl_close($ch);
    return $content;
}

// Function to parse transcript from fetched content
function parseTranscript($content) {
    if ($content === false) return false;

    $content = mb_convert_encoding($content, 'HTML-ENTITIES', 'UTF-8');

    // Parse HTML
    $dom = new DOMDocument();
    libxml_use_internal_errors(true);
    $dom->loadHTML($content);
    libxml_clear_errors();
    $xpath = new DOMXPath($dom);

    // Extract title
    $titleNode = $xpath->query("//h1[contains(@class, 'card-title')]");
    $title = $titleNode->length > 0 ? trim($titleNode->item(0)->textContent) : "Title not found.";

    // Extract transcript
    $transcriptDiv = $xpath->query("//div[@id='transcript']");
    $transcript = $transcriptDiv->length > 0 ? preg_replace('/\s+/', ' ', trim($transcriptDiv->item(0)->textContent)) : "Transcript not found.";

    return [
        'title' => $title,
        'transcript' => $transcript,
    ];
}

// Flush partial output (prevents web server from timing out)
while (ob_get_level()) {
    ob_end_clean();
}
header('Content-Encoding: none');
ob_implicit_flush(true);
set_time_limit(0); // Disable PHP execution time limit


// Attempt to fetch Hindi transcript
$htmlContent = fetchContent($urlHindi);
$result = parseTranscript($htmlContent);


// Final output
if ($result === false ) {
      echo "Failed to fetch Hindi transcript.\n";

} elseif ($result['transcript'] === "Transcript not found."){
       echo "Hindi transcript not found for this video.\n";
}
 else {
    echo $result['title'] . "\n\n" . trim(str_replace("Back To Top", "", $result['transcript']));
}
?>